@@ -25,9 +25,9 @@ from oslo.config import cfg
 from oslo.messaging._drivers import amqp as rpc_amqp
 from oslo.messaging._drivers import amqpdriver
 from oslo.messaging._drivers import common as rpc_common
+from oslo.messaging._i18n import _
 from oslo.messaging import exceptions
-from oslo.messaging.openstack.common.gettextutils import _
-from oslo.messaging.openstack.common import jsonutils
+from oslo.serialization import jsonutils
 from oslo.utils import importutils
 from oslo.utils import netutils
 
@@ -227,7 +227,6 @@ class DirectConsumer(ConsumerBase):
         """
 
         link_opts = {
-            "auto-delete": conf.amqp_auto_delete,
             "exclusive": True,
             "durable": conf.amqp_durable_queues,
         }
@@ -478,6 +477,9 @@ class Connection(object):
                 hostname, port = netutils.parse_host_port(
                     adr, default_port=5672)
 
+                if ':' in hostname:
+                    hostname = '[' + hostname + ']'
+
                 params = {
                     'host': '%s:%d' % (hostname, port),
                     'username': self.conf.qpid_username,
@@ -721,7 +723,7 @@ class QpidDriver(amqpdriver.AMQPDriverBase):
         conf.register_opts(qpid_opts)
         conf.register_opts(rpc_amqp.amqp_opts)
 
-        connection_pool = rpc_amqp.get_connection_pool(conf, url, Connection)
+        connection_pool = rpc_amqp.ConnectionPool(conf, url, Connection)
 
         super(QpidDriver, self).__init__(conf, url,
                                          connection_pool,
